<h1 align="center">Furo</h1>
<p align="center">
  A clean customizable theme for <a href="https://www.sphinx-doc.org/">Sphinx</a>.
</p>
<a href="https://pradyunsg.me/furo/">
  <img align="center" src="https://github.com/pradyunsg/furo/raw/main/docs/_static/demo.png" alt="Demo image">
</a>

## Quickstart

Furo can be installed using `pip`:

```
pip install furo
```

Update the `html_theme` in `conf.py`:

```py
html_theme = "furo"
```

Your Sphinx documentation will now be generated with this theme! For more information, visit [Furo's documentation][docs].

[docs]: https://pradyunsg.me/furo/

## Contributing

Furo is a volunteer maintained open source project, and we welcome contributions of all forms. Please take a look at our [Contributing Guide](https://pradyunsg.me/furo/contributing/) for more information.

## Acknowledgements

Furo is inspired by (and borrows elements from) some excellent technical documentation themes:

- [mkdocs-material] for MkDocs
- [Just the Docs] for Jekyll
- [GitBook]

We use [BrowserStack] to test on real devices and browsers. Shoutout to them for supporting OSS projects!

[mkdocs-material]: https://squidfunk.github.io/mkdocs-material/
[just the docs]: https://pmarsceill.github.io/just-the-docs/
[gitbook]: https://www.gitbook.com/
[browserstack]: https://browserstack.com/

## License

This project is licensed under the MIT License.
